@@ -212,7 +212,10 @@ class bigQuery(object):
 
                 if "schema" in list(config_object.keys()):
                     job_config.schema = config_object["schema"]
+                elif self.exists == True:
+                    job_config.schema = self.table.schema
                 else:
+
                     job_config.autodetect = True
 
 
